===============================
Contributing to django Organice
===============================

Official repositories: (kept in sync)

#. Bitbucket: https://bitbucket.org/bittner/django-organice
#. GitHub: https://github.com/bittner/django-organice

Fork any of the repositories, make your code changes or additions, and place a pull request.

Help Wanted
===========

- Writing tests
- Translations (blog posts, documentation, user interface)

Translation
-----------

Translation is done on Transifex_ for both the project text strings and the documentation.

The multilingual documentation is written in reStructuredText_ syntax, and built using Sphinx_.
As a translator you can simply jump on Transifex and get your hands dirty for your language.
Some helpful background reading is available from `Read the Docs`_ and `Transifex support`_.

Bumping Versions, Package, Release
==================================

As for the version numbers of django Organice we use `Semantic Versioning`_.


.. _Transifex: https://www.transifex.com/projects/p/django-organice-docs/
.. _reStructuredText: http://docutils.sourceforge.net/docs/user/rst/quickref.html
.. _Sphinx: http://sphinx-doc.org/intl.html
.. _`Read the Docs`: http://read-the-docs.readthedocs.org/en/latest/i18n.html
.. _`Transifex support`: http://support.transifex.com/customer/portal/articles/972120-introduction-to-the-web-editor
.. _`Semantic Versioning`: http://semver.org/

